@@ -941,10 +941,10 @@ class Shvar(RememberInstanceCreationInfo):
         
         # varname, time = Filename.split('_')
         # Hour, Minute, Second = time.split('-')
-        Second  = Filename[-2:]
-        Minute  = Filename[-5:-3]
-        Hour    = Filename[-8:-6]
-        varname = Filename[:-9]
+        Second  = Filename[-6:-4]
+        Minute  = Filename[-11:-7]
+        Hour    = Filename[-12:-10]
+        varname = Filename[:-13]
         print(varname, Hour, Minute, Second)
         return [varname, Hour, Minute]
     
